/**
 * react-custom-search-list - A customizable React search input component with dynamic popup suggestions, allowing developers to create unique search experiences.
 *
 * @version v2.2.1
 * @homepage https://github.com/dev-javascript/react-custom-search-list#readme
 * @author dev-javascript javascript.code.dev@gmail.com
 * @license MIT
 */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('react'), require('@popperjs/core/lib/popper-lite'), require('@popperjs/core/lib/modifiers/flip'), require('@popperjs/core/lib/modifiers/preventOverflow'), require('@popperjs/core/lib/modifiers/computeStyles')) :
  typeof define === 'function' && define.amd ? define(['react', '@popperjs/core/lib/popper-lite', '@popperjs/core/lib/modifiers/flip', '@popperjs/core/lib/modifiers/preventOverflow', '@popperjs/core/lib/modifiers/computeStyles'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.ReactCustomSearchList = factory(global.React, global.Popper, global.Popper.flip, global.Popper.preventOverflow, global.Popper.computeStyles));
})(this, (function (React, popperLite, flip, preventOverflow, computeStyles) { 'use strict';

  preventOverflow.options = {
    padding: 0,
    boundariesElement: 'viewport'
  };
  function createPopper (ref, popper, fullWidth, placement) {
    var op = {
      placement: placement,
      strategy: 'fixed',
      modifiers: [flip, preventOverflow]
    };
    if (fullWidth == true) {
      op.placement = 'bottom-start';
      op.modifiers.push({
        name: 'sameWidth',
        enabled: true,
        fn: function fn(_ref) {
          var state = _ref.state;
          state.styles.popper.width = state.rects.reference.width + "px";
        },
        phase: 'beforeWrite',
        requires: [computeStyles]
      });
    }
    return popperLite.createPopper(ref, popper, op);
  }

  /**
   *
   * @param {Object} btnEl
   * @param {Number} margin
   */
  function getPopperMaxHeight (btnEl, margin) {
    var _btnEl$getBoundingCli = btnEl.getBoundingClientRect(),
      top = _btnEl$getBoundingCli.top,
      bottom = _btnEl$getBoundingCli.bottom;
    bottom = Math.max(document.documentElement.clientHeight || 0, window.innerHeight || 0) - bottom;
    return Math.max(top, bottom) - margin;
  }

  /**
   *
   * @param {Object} popperEl
   * @param {Number} marginRight
   * @return {Number}
   */
  function getPopperMaxWidth (popperEl, marginRight) {
    var _popperEl$getBounding = popperEl.getBoundingClientRect(),
      left = _popperEl$getBounding.left;
    var maxWidth = Math.max(document.documentElement.clientWidth || 0, window.innerWidth || 0) - left - marginRight;
    return maxWidth;
  }

  function Popper$1(getDeps, props) {
    var _getDeps = getDeps(),
      createPopper = _getDeps.createPopper,
      getPopperMaxHeight = _getDeps.getPopperMaxHeight,
      getPopperMaxWidth = _getDeps.getPopperMaxWidth;
    var rootRef = props.rootRef,
      children = props.children,
      style = props.style,
      fullWidth = props.fullWidth,
      placement = props.placement;
    var popperRef = React.useRef();
    var ref = React.useRef();
    ref.current = ref.current || {};
    React.useLayoutEffect(function () {
      popperRef.current.style.maxHeight = getPopperMaxHeight(rootRef.current, 8) + 'px';
      var popperIns = createPopper(rootRef.current, popperRef.current, fullWidth, placement);
      ref.current.popperIns = popperIns;
      return function () {
        popperIns.destroy();
      };
    }, []);
    React.useLayoutEffect(function () {
      ref.current && ref.current.popperIns && ref.current.popperIns.update().then(function () {
        popperRef.current.style.maxWidth = getPopperMaxWidth(popperRef.current, 8) + 'px';
      });
    }, [children]);
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
      ref: popperRef,
      className: "rc-search-suggestions-popper",
      style: style,
      tabIndex: 0
    }, children));
  }

  var getDeps = function getDeps() {
    return {
      createPopper: createPopper,
      getPopperMaxHeight: getPopperMaxHeight,
      getPopperMaxWidth: getPopperMaxWidth
    };
  };
  var Popper = Popper$1.bind(null, getDeps);

  function MagnifierIcon (props /* eslint-disable-line no-unused-vars */) {
    return /*#__PURE__*/React.createElement("svg", {
      className: "sc-bcXHqe hVRzLL search-icon",
      width: "20",
      height: "20",
      focusable: "false",
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 24 24",
      fill: "gray",
      style: {
        backgroundColor: 'white'
      }
    }, /*#__PURE__*/React.createElement("path", {
      d: "M15.5 14h-.79l-.28-.27C15.41 12.59 16 11.11 16 9.5 16 5.91 13.09 3 9.5 3S3 5.91 3 9.5 5.91 16 9.5 16c1.61 0 3.09-.59 4.23-1.57l.27.28v.79l5 4.99L20.49 19l-4.99-5zm-6 0C7.01 14 5 11.99 5 9.5S7.01 5 9.5 5 14 7.01 14 9.5 11.99 14 9.5 14z"
    }));
  }

  function ClearIcon (props) {
    var value = props.value,
      onClear = props.onClear;
    return /*#__PURE__*/React.createElement("svg", {
      width: "20",
      height: "20",
      focusable: "false",
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 24 24",
      fill: "gray",
      onClick: function onClick(e) {
        onClear(e);
      },
      style: {
        backgroundColor: 'white',
        cursor: 'pointer',
        opacity: value.length ? 1 : 0
      }
    }, /*#__PURE__*/React.createElement("path", {
      d: "M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.58 12 5 17.58 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"
    }));
  }

  function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
  /**
   *
   * @param {Object} props
   * @param {React.ReactNode} [props.children=null] - will be shown in popup
   * @param {value} props.value - input value
   * @param {Function} props.onChange - onChange function for input
   * @param {Object} [props.rootStyle={}] - style object of the root element
   * @param {Object} [props.inputContainerStyle={}] - style object of the parent element of text input
   * @param {Object} [props.inputStyle={}] - style object of the input element
   * @param {String} [props.placeholder="search"]
   * @param {Function} [props.onKeyDown=()=>{}] - keydown event for input
   * @param {Function} [props.onFocus=()=>{}] - focus event for input
   * @param {Function} [props.onBlur=()=>{}] - blur event for the input
   * @param {Object} [props.popperStyle={}] - style object for popper container
   * @param {Boolean} [props.fullWidth=true] - set popper width same as input
   * @param {'auto'| 'auto-start'| 'auto-end'| 'top'| 'top-start'| 'top-end'| 'bottom'| 'bottom-start'| 'bottom-end'| 'right'| 'right-start'| 'right-end'| 'left'| 'left-start'| 'left-end'} [props.placement="bottom-start"] - popper's placement
   * @param {React.FC} [props.ClearIconComponent=ClearIcon] - custom Clear icon
   * @param {React.FC} [props.MagnifierIconComponent=MagnifierIcon] - custom Magnifier icon
   * @param {Function} [props.onClear=()=>{}] - triggerd when the user clicks on the default Clear icon
   * @param {"underline"|"outline"|"panel"} [props.theme="outline"] - searchbox theme
   * @param {Boolean} [props.corner=true] - if set true then border-radius would be "5px"
   * @param {Boolean} [props.autoFocus=false] - autoFocus attribute for the input element
   * @param {String} [props.inputName=""] - name attribute for the input element
   * @param {Boolean} [props.openOnClick=true] - if it is true then the suggestion list will be open when the user clicks on the input
   * @param {(e)=>Boolean} [props.openOnKeyDown=(e)=>e.key === 'Enter'] -it it returns true then the suggestion list will be open
   */
  function ReactCustomSearchList(props) {
    var _props$children = props.children,
      children = _props$children === void 0 ? null : _props$children,
      _props$value = props.value,
      value = _props$value === void 0 ? '' : _props$value,
      onChange = props.onChange,
      _props$rootStyle = props.rootStyle,
      rootStyle = _props$rootStyle === void 0 ? {} : _props$rootStyle,
      _props$inputContainer = props.inputContainerStyle,
      inputContainerStyle = _props$inputContainer === void 0 ? {} : _props$inputContainer,
      _props$inputStyle = props.inputStyle,
      inputStyle = _props$inputStyle === void 0 ? {} : _props$inputStyle,
      _props$placeholder = props.placeholder,
      placeholder = _props$placeholder === void 0 ? 'search' : _props$placeholder,
      _props$onKeyDown = props.onKeyDown,
      onKeyDown = _props$onKeyDown === void 0 ? function () {} : _props$onKeyDown,
      _props$onFocus = props.onFocus,
      onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
      _props$onBlur = props.onBlur,
      onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
      _props$popperStyle = props.popperStyle,
      popperStyle = _props$popperStyle === void 0 ? {} : _props$popperStyle,
      _props$fullWidth = props.fullWidth,
      fullWidth = _props$fullWidth === void 0 ? true : _props$fullWidth,
      _props$placement = props.placement,
      placement = _props$placement === void 0 ? 'bottom-start' : _props$placement,
      _props$ClearIconCompo = props.ClearIconComponent,
      ClearIconComponent = _props$ClearIconCompo === void 0 ? ClearIcon : _props$ClearIconCompo,
      _props$MagnifierIconC = props.MagnifierIconComponent,
      MagnifierIconComponent = _props$MagnifierIconC === void 0 ? MagnifierIcon : _props$MagnifierIconC,
      _props$onClear = props.onClear,
      onClear = _props$onClear === void 0 ? function () {} : _props$onClear,
      _props$theme = props.theme,
      theme = _props$theme === void 0 ? 'outline' : _props$theme,
      _props$corner = props.corner,
      corner = _props$corner === void 0 ? true : _props$corner,
      _props$autoFocus = props.autoFocus,
      autoFocus = _props$autoFocus === void 0 ? false : _props$autoFocus,
      _props$inputName = props.inputName,
      inputName = _props$inputName === void 0 ? '' : _props$inputName,
      _props$openOnClick = props.openOnClick,
      openOnClick = _props$openOnClick === void 0 ? true : _props$openOnClick,
      _props$openOnKeyDown = props.openOnKeyDown,
      openOnKeyDown = _props$openOnKeyDown === void 0 ? function (e) {
        return e.key === 'Enter' || e.keyCode === 13;
      } : _props$openOnKeyDown;
    var _useState = React.useState(false),
      open = _useState[0],
      setOpen = _useState[1];
    var rootRef = React.useRef();
    var onClickHandler = React.useCallback(function () {
      openOnClick && setOpen(true);
    }, [openOnClick]);
    var onKeyDownHandler = React.useCallback(function (e) {
      if (openOnKeyDown(e) == true) {
        setOpen(true);
      }
      onKeyDown(e);
    }, [onKeyDown, openOnKeyDown]);
    React.useEffect(function () {
      var rEl = document.documentElement,
        input = rootRef.current.querySelector('input');
      var mousedown = function mousedown(e) {
        return open && e.target == input && e.stopImmediatePropagation();
      };
      rEl.addEventListener('click', mousedown, {
        useCapture: true
      });
      return function () {
        rEl.removeEventListener('click', mousedown, {
          useCapture: true
        });
      };
    }, [open]);
    React.useEffect(function () {
      var click = function click() {
        setTimeout(function () {
          setOpen(false);
        });
      };
      open ? document.documentElement.addEventListener('click', click, {
        once: true,
        useCapture: true
      }) : document.documentElement.removeEventListener('click', click, {
        once: true,
        useCapture: true
      });
      return function () {
        if (open) {
          document.documentElement.removeEventListener('click', click, {
            once: true,
            useCapture: true
          });
        }
      };
    }, [open]);
    return /*#__PURE__*/React.createElement("div", {
      className: "rc-search-suggestions-root " + theme + (corner ? ' corner' : ''),
      style: rootStyle
    }, open && children != null && children.length !== 0 ? /*#__PURE__*/React.createElement(Popper, {
      rootRef: rootRef,
      style: popperStyle,
      fullWidth: theme === 'panel' ? true : fullWidth,
      placement: placement
    }, children) : null, /*#__PURE__*/React.createElement("div", {
      className: "rc-search-suggestions-container",
      ref: rootRef,
      style: inputContainerStyle
    }, MagnifierIconComponent ? /*#__PURE__*/React.createElement(MagnifierIconComponent, null) : null, /*#__PURE__*/React.createElement("input", _extends({
      value: value,
      onChange: onChange,
      onFocus: onFocus,
      onClick: onClickHandler,
      onKeyDown: onKeyDownHandler,
      onBlur: onBlur,
      placeholder: placeholder,
      style: inputStyle,
      autoFocus: autoFocus
    }, inputName ? {
      name: inputName
    } : {})), ClearIconComponent ? /*#__PURE__*/React.createElement(ClearIconComponent, {
      value: value,
      onClear: onClear
    }) : null, /*#__PURE__*/React.createElement("div", {
      className: "rc-search-suggestions-divider rc-search-suggestions-divider-bottom"
    }), /*#__PURE__*/React.createElement("div", {
      className: "rc-search-suggestions-divider rc-search-suggestions-divider-top"
    })));
  }

  return ReactCustomSearchList;

}));
//# sourceMappingURL=react-custom-search-list.umd.js.map
